#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Enter the description of your new custom indicator here
    /// </summary>
    [Description("Enter the description of your new custom indicator here")]
    public class RangeBarCloseMarker : Indicator
    {
        #region Variables
        // Wizard generated variables
            private int barsize = 2; 
			private Color markercolor = Color.Blue;
			private int thickness = 2;
			private int text_offset = 10;
			public bool show_marker = true;
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            Overlay				= true;
			CalculateOnBarClose = false;
        }
        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			if (CurrentBar<10)
				return;
			int decimals = 0;
			if (TickSize == .1) decimals = 1;
			if (TickSize == .25) decimals = 2;
			if (TickSize == .01) decimals = 2;
			if (TickSize == .025) decimals = 3;
			if (TickSize == .001) decimals = 3;
			if (TickSize == .0025) decimals = 4;
			if (TickSize == .0001) decimals = 4;

			
			double upper = Math.Round(Low[0]+(barsize)*TickSize,decimals);
			double lower = Math.Round(High[0]-(barsize)*TickSize,decimals);
			if(show_marker == true){
			DrawLine("upper",false,-1,upper,0,upper,markercolor,DashStyle.Solid,thickness);
			DrawLine("lower",false,-1,lower,0,lower,markercolor,DashStyle.Solid,thickness);}
			DrawText("uppertext",upper.ToString("0.0000"),-text_offset,upper,markercolor);
			DrawText("lowertext",lower.ToString("0.0000"),-text_offset,lower,markercolor);
			
        }

        #region Properties
        [Description("What size range bar are you using?")]
        [GridCategory("Parameters")]
        public int Bar_Size
        {
            get { return barsize; }
            set { barsize = Math.Max(1, value); }
        }
		[Description("Thickness of the marker")]
        [GridCategory("Parameters")]
        public int Marker_Thickness
        {
            get { return thickness; }
            set { thickness = Math.Max(1, value); }
        }
		[Description("Show the markers")]
        [GridCategory("Parameters")]
        public bool Show_Marker
        {
            get { return show_marker; }
            set { show_marker = value; }
        }
		[Description("Offset from price into right margin for text.")]
        [GridCategory("Parameters")]
        public int Text_Offset
        {
            get { return text_offset; }
            set { text_offset = Math.Max(1, value); }
        }
		[Description("Color of the marker")]
        [GridCategory("Parameters")]
        public Color Marker_Color
        {
            get { return markercolor; }
            set { markercolor = value; }
        }
		// Serialize Color object
		[Browsable(false)]
		public string MarkerColorSerialize
		{
			get { return NinjaTrader.Gui.Design.SerializableColor.ToString(markercolor); }
			set { markercolor = NinjaTrader.Gui.Design.SerializableColor.FromString(value); }
		}
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private RangeBarCloseMarker[] cacheRangeBarCloseMarker = null;

        private static RangeBarCloseMarker checkRangeBarCloseMarker = new RangeBarCloseMarker();

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public RangeBarCloseMarker RangeBarCloseMarker(int bar_Size, Color marker_Color, int marker_Thickness, bool show_Marker, int text_Offset)
        {
            return RangeBarCloseMarker(Input, bar_Size, marker_Color, marker_Thickness, show_Marker, text_Offset);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public RangeBarCloseMarker RangeBarCloseMarker(Data.IDataSeries input, int bar_Size, Color marker_Color, int marker_Thickness, bool show_Marker, int text_Offset)
        {
            if (cacheRangeBarCloseMarker != null)
                for (int idx = 0; idx < cacheRangeBarCloseMarker.Length; idx++)
                    if (cacheRangeBarCloseMarker[idx].Bar_Size == bar_Size && cacheRangeBarCloseMarker[idx].Marker_Color == marker_Color && cacheRangeBarCloseMarker[idx].Marker_Thickness == marker_Thickness && cacheRangeBarCloseMarker[idx].Show_Marker == show_Marker && cacheRangeBarCloseMarker[idx].Text_Offset == text_Offset && cacheRangeBarCloseMarker[idx].EqualsInput(input))
                        return cacheRangeBarCloseMarker[idx];

            lock (checkRangeBarCloseMarker)
            {
                checkRangeBarCloseMarker.Bar_Size = bar_Size;
                bar_Size = checkRangeBarCloseMarker.Bar_Size;
                checkRangeBarCloseMarker.Marker_Color = marker_Color;
                marker_Color = checkRangeBarCloseMarker.Marker_Color;
                checkRangeBarCloseMarker.Marker_Thickness = marker_Thickness;
                marker_Thickness = checkRangeBarCloseMarker.Marker_Thickness;
                checkRangeBarCloseMarker.Show_Marker = show_Marker;
                show_Marker = checkRangeBarCloseMarker.Show_Marker;
                checkRangeBarCloseMarker.Text_Offset = text_Offset;
                text_Offset = checkRangeBarCloseMarker.Text_Offset;

                if (cacheRangeBarCloseMarker != null)
                    for (int idx = 0; idx < cacheRangeBarCloseMarker.Length; idx++)
                        if (cacheRangeBarCloseMarker[idx].Bar_Size == bar_Size && cacheRangeBarCloseMarker[idx].Marker_Color == marker_Color && cacheRangeBarCloseMarker[idx].Marker_Thickness == marker_Thickness && cacheRangeBarCloseMarker[idx].Show_Marker == show_Marker && cacheRangeBarCloseMarker[idx].Text_Offset == text_Offset && cacheRangeBarCloseMarker[idx].EqualsInput(input))
                            return cacheRangeBarCloseMarker[idx];

                RangeBarCloseMarker indicator = new RangeBarCloseMarker();
                indicator.BarsRequired = BarsRequired;
                indicator.CalculateOnBarClose = CalculateOnBarClose;
#if NT7
                indicator.ForceMaximumBarsLookBack256 = ForceMaximumBarsLookBack256;
                indicator.MaximumBarsLookBack = MaximumBarsLookBack;
#endif
                indicator.Input = input;
                indicator.Bar_Size = bar_Size;
                indicator.Marker_Color = marker_Color;
                indicator.Marker_Thickness = marker_Thickness;
                indicator.Show_Marker = show_Marker;
                indicator.Text_Offset = text_Offset;
                Indicators.Add(indicator);
                indicator.SetUp();

                RangeBarCloseMarker[] tmp = new RangeBarCloseMarker[cacheRangeBarCloseMarker == null ? 1 : cacheRangeBarCloseMarker.Length + 1];
                if (cacheRangeBarCloseMarker != null)
                    cacheRangeBarCloseMarker.CopyTo(tmp, 0);
                tmp[tmp.Length - 1] = indicator;
                cacheRangeBarCloseMarker = tmp;
                return indicator;
            }
        }
    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.RangeBarCloseMarker RangeBarCloseMarker(int bar_Size, Color marker_Color, int marker_Thickness, bool show_Marker, int text_Offset)
        {
            return _indicator.RangeBarCloseMarker(Input, bar_Size, marker_Color, marker_Thickness, show_Marker, text_Offset);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public Indicator.RangeBarCloseMarker RangeBarCloseMarker(Data.IDataSeries input, int bar_Size, Color marker_Color, int marker_Thickness, bool show_Marker, int text_Offset)
        {
            return _indicator.RangeBarCloseMarker(input, bar_Size, marker_Color, marker_Thickness, show_Marker, text_Offset);
        }
    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.RangeBarCloseMarker RangeBarCloseMarker(int bar_Size, Color marker_Color, int marker_Thickness, bool show_Marker, int text_Offset)
        {
            return _indicator.RangeBarCloseMarker(Input, bar_Size, marker_Color, marker_Thickness, show_Marker, text_Offset);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public Indicator.RangeBarCloseMarker RangeBarCloseMarker(Data.IDataSeries input, int bar_Size, Color marker_Color, int marker_Thickness, bool show_Marker, int text_Offset)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.RangeBarCloseMarker(input, bar_Size, marker_Color, marker_Thickness, show_Marker, text_Offset);
        }
    }
}
#endregion
